@@ -4,6 +4,7 @@ from .lemur import Lemur
 from .transcriber import RealtimeTranscriber, Transcriber, Transcript, TranscriptGroup
 from .types import (
     AssemblyAIError,
+    AudioEncoding,
     AutohighlightResponse,
     AutohighlightResult,
     Chapter,
@@ -44,6 +45,7 @@ from .types import (
     Sentiment,
     SentimentType,
     Settings,
+    SpeechModel,
     StatusResult,
     SummarizationModel,
     SummarizationType,
@@ -65,6 +67,7 @@ settings = Settings()
 __all__ = [
     # types
     "AssemblyAIError",
+    "AudioEncoding",
     "AutohighlightResponse",
     "AutohighlightResult",
     "Chapter",
@@ -99,6 +102,7 @@ __all__ = [
     "Sentiment",
     "SentimentType",
     "Settings",
+    "SpeechModel",
     "StatusResult",
     "SummarizationModel",
     "SummarizationType",
